==> claromentis-knowledgebase-4.1.6-14478180.zip: classes/KBFilter.php <==
<?php
namespace Claromentis\Knowledgebase;

$GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"] = (@$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] ?: array()) + array();
use Claromentis\Core\Application;




class KBFilter extends \ErrorHandler
{
    
    
    
    
    protected $num_rows;
    
    
    
    
    protected $skip_rows;
    
    
    
    
    protected $order_by;
    
    
    
    
    protected $order_dir;
    
    
    
    
    protected $subscriptions;
    
    
    
    
    public function GetNumRows()
    {
        return $this->num_rows;
    }
    
    
    
    
    
    public function SetNumRows($value)
    {
        $this->num_rows = $value;
        return $this;
    }
    
    
    
    
    public function GetSkipRows()
    {
        return $this->skip_rows;
    }
    
    
    
    
    
    public function SetSkipRows($value)
    {
        $this->skip_rows = $value;
        return $this;
    }
    
    
    
    
    public function GetOrderBy()
    {
        return $this->order_by;
    }
    
    
    
    
    
    
    
    public function SetOrderBy($value, Application $_6eb6fcb92c942851e079f8ec5fb80324 = null, $session_key = 'SESSION_kb_default_sort')
    {
        
        
        
        
        global $g_application;
        if ($_6eb6fcb92c942851e079f8ec5fb80324 === null) {
            $_6eb6fcb92c942851e079f8ec5fb80324 = $g_application;
        }
        if (!$_6eb6fcb92c942851e079f8ec5fb80324->session->get($session_key) || $value !== $_6eb6fcb92c942851e079f8ec5fb80324->session->get($session_key)) {
            $_6eb6fcb92c942851e079f8ec5fb80324->session->set($session_key, $value);
        }
        $this->order_by = $value;
        return $this;
    }
    
    
    
    
    public function GetOrderDir()
    {
        return $this->order_dir;
    }
    
    
    
    
    
    public function SetOrderDir($value)
    {
        $this->order_dir = $value;
        return $this;
    }
    
    
    
    
    public function GetSubscriptions()
    {
        return $this->subscriptions;
    }
    
    
    
    
    
    public function SetSubscriptions($value)
    {
        $this->subscriptions = (bool) $value;
        return $this;
    }
}

==> claromentis-knowledgebase-5.0.8-499ab622.zip: classes/KBFilter.php <==
<?php
namespace Claromentis\Knowledgebase;

$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"] ?: array()) + array();
use Claromentis\Core\Application;




class KBFilter extends \ErrorHandler
{
    
    
    
    
    protected $num_rows;
    
    
    
    
    protected $skip_rows;
    
    
    
    
    protected $order_by;
    
    
    
    
    protected $order_dir;
    
    
    
    
    protected $subscriptions;
    
    
    
    
    public function GetNumRows()
    {
        return $this->num_rows;
    }
    
    
    
    
    
    public function SetNumRows($value)
    {
        $this->num_rows = $value;
        return $this;
    }
    
    
    
    
    public function GetSkipRows()
    {
        return $this->skip_rows;
    }
    
    
    
    
    
    public function SetSkipRows($value)
    {
        $this->skip_rows = $value;
        return $this;
    }
    
    
    
    
    public function GetOrderBy()
    {
        return $this->order_by;
    }
    
    
    
    
    
    
    
    public function SetOrderBy($value, Application $_6eb6fcb92c942851e079f8ec5fb80324 = null, $session_key = 'SESSION_kb_default_sort')
    {
        
        
        
        
        global $g_application;
        if ($_6eb6fcb92c942851e079f8ec5fb80324 === null) {
            $_6eb6fcb92c942851e079f8ec5fb80324 = $g_application;
        }
        if (!$_6eb6fcb92c942851e079f8ec5fb80324->session->get($session_key) || $value !== $_6eb6fcb92c942851e079f8ec5fb80324->session->get($session_key)) {
            $_6eb6fcb92c942851e079f8ec5fb80324->session->set($session_key, $value);
        }
        $this->order_by = $value;
        return $this;
    }
    
    
    
    
    public function GetOrderDir()
    {
        return $this->order_dir;
    }
    
    
    
    
    
    public function SetOrderDir($value)
    {
        $this->order_dir = $value;
        return $this;
    }
    
    
    
    
    public function GetSubscriptions()
    {
        return $this->subscriptions;
    }
    
    
    
    
    
    public function SetSubscriptions($value)
    {
        $this->subscriptions = (bool) $value;
        return $this;
    }
}
